__author__ = "Rust Saiargaliev"
__email__ = "hi@amureki.me"
__url__ = "https://github.com/amureki/statuscheck"
__version__ = "3.2.0"
